import type {UserListResponseModel, ListViewConfig} from '@/helpers/models';
import {fetchAuthenticated} from '@/helpers/retrieveData';
import {useLoginStore} from '@/stores/login';
import i18n from 'i18next';

const fetchListViewConfigMocked = (): ListViewConfig => ({
  url: 'str',
  allowedGlobalActions: [],
  searchFormOptions: {
    schools: [
      {
        value: 'DEMOSCHOOL',
        label: 'DEMOSCHOOL',
      }, {
        value: 'School1',
        label: 'Schule 1',
      },
    ],
    activationStates: [
      {
        value: 'aktiviert',
        label: 'Aktiviert',
      }, {
        value: 'deactivated',
        label: 'Deaktiviert',
      },
    ],
    roles: [
      {
        value: 'rolea',
        label: 'Role A',
      }, {
        value: 'roleb',
        label: 'Role B',
      },
    ],
    schoolClasses: {
      DEMOSCHOOL: [
        {
          value: 'classa',
          label: 'Class A',
        },
        {
          value: 'classb',
          label: 'Class B',
        },
      ],
      School1: [
        {
          value: 'classc',
          label: 'Class C',
        },
        {
          value: 'classd',
          label: 'Class D',
        },
      ],
    },

  },
  columns: [
    {
      label: 'Last name',
      attribute: 'lastname',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'First name',
      attribute: 'firstname',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'User name',
      attribute: 'username',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Schools',
      attribute: 'schools',
      // sorting: 'asc',
      formatter: 'return value.join(", ")',
    },
    {
      label: 'Primary mail address',
      attribute: 'email',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Activation state',
      attribute: 'disabled',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Role',
      attribute: 'ucsschool_roles',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Source UID',
      attribute: 'source_uid',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Record UID',
      attribute: 'record_uid',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Creation date',
      attribute: 'create_timestamp',
      // sorting: 'asc',
      // eslint-disable-next-line no-template-curly-in-string
      formatter: 'const d = new Date(value); return `${d.toLocaleDateString()} ${d.toLocaleTimeString()}`;',
    },
    {
      label: 'Date of last change',
      attribute: 'modify_timestamp',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Account activation date',
      attribute: 'account_activation_date',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Account expiry date',
      attribute: 'expiration_date',
      // sorting: 'asc',
      formatter: '',
    },
    {
      label: 'Scheduled deletion date',
      attribute: 'ucsschool_purge_timestamp',
      // sorting: 'asc',
      formatter: '',
    },
  ],
});

export const fetchListViewConfig = async function(): Promise<ListViewConfig> {
  if (import.meta.env.VITE_USE_REAL_BACKEND === 'false') {
    console.warn('fetchListViewConfig. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    return fetchListViewConfigMocked();
  }

  const loginStore = useLoginStore();
  const answer = await fetchAuthenticated(`/ucsschool/bff-users/v1/pages/listView/settings/${loginStore.username}`, {
    headers: {
      'accept': 'application/json',
      'Accept-Language': i18n.language,
    },
  });

  return await answer.json();
};


/* eslint-disable camelcase */
const fetchUsersMocked = (): UserListResponseModel[] => [
  {
    id: 'user1',
    allowedActions: ['delete'],
    attributes: {
      lastname: {
        value: 'Mustermann',
        access: 'read',
      },
      firstname: {
        value: 'Max',
        access: 'read',
      },
      name: {
        value: 'max.mustermann',
        access: 'read',
      },
      schools: {
        value: ['DEMOSCHOOL'],
        access: 'read',
      },
      school: {
        value: 'string string string string ',
        access: 'read',
      },
      email: {
        value: 'string',
        access: 'read',
      },
      disabled: {
        value: false,
        access: 'read',
      },
      ucsschool_roles: {
        value: ['teacher:school:DEMOSCHOOL'],
        access: 'read',
      },
      source_uid: {
        value: 'KELVIN',
        access: 'none',
      },
      record_uid: {
        value: 'mmrecord',
        access: 'none',
      },
      create_timestamp: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      modify_timestamp: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      account_activation_date: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      expiration_date: {
        value: '2022-08-26',
        access: 'none',
      },
      ucsschool_purge_timestamp: {
        value: '2022-08-26',
        access: 'none',
      },
    },
  }, {
    id: 'user2',
    allowedActions: ['delete'],
    attributes: {
      lastname: {
        value: 'Musterfrau',
        access: 'read',
      },
      firstname: {
        value: 'Mina',
        access: 'read',
      },
      name: {
        value: 'mina.musterfrau',
        access: 'read',
      },
      schools: {
        value: ['DEMOSCHOOL'],
        access: 'read',
      },
      school: {
        value: 'string',
        access: 'read',
      },
      email: {
        value: 'string',
        access: 'read',
      },
      disabled: {
        value: false,
        access: 'read',
      },
      ucsschool_roles: {
        value: ['teacher:school:DEMOSCHOOL'],
        access: 'read',
      },
      source_uid: {
        value: 'KELVIN',
        access: 'none',
      },
      record_uid: {
        value: 'mmfraurecord',
        access: 'none',
      },
      create_timestamp: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      modify_timestamp: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      account_activation_date: {
        value: '2022-08-26T09:46:35.422Z',
        access: 'none',
      },
      expiration_date: {
        value: '2022-08-26',
        access: 'none',
      },
      ucsschool_purge_timestamp: {
        value: '2022-08-26',
        access: 'none',
      },
    },
  },
];
/* eslint-enable camelcase */

export const fetchUsers = async(
  school: string,
  group: string,
  role: string,
  sourceUid: string,
  state: string,
  quickSearch: string,
): Promise<UserListResponseModel[]> => {
  if (import.meta.env.VITE_USE_REAL_BACKEND === 'false') {
    console.warn('fetchUsers. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    return fetchUsersMocked();
  }

  const urlSearchParams = new URLSearchParams({});
  if (group !== '') {
    urlSearchParams.append('group', group);
  }
  if (role !== '') {
    urlSearchParams.append('role', role);
  }
  if (sourceUid !== '') {
    urlSearchParams.append('sourceUid', sourceUid);
  }
  if (quickSearch !== '') {
    urlSearchParams.append('quickSearch', quickSearch);
  }
  if (state !== '') {
    urlSearchParams.append('disabled', (state === 'disabled').toString());
  }
  const answer = await fetchAuthenticated(`/ucsschool/bff-users/v1/users/search/${school}?${urlSearchParams.toString()}`, {
    headers: {
      'accept': 'application/json',
      'Accept-Language': 'en',
    },
  });

  return await answer.json();
};
